#[non_exhaustive]
pub enum Request { Destroy, GetPreferred { image_description: New<WpImageDescriptionV1>, }, GetPreferredParametric { image_description: New<WpImageDescriptionV1>, }, }
Available on crate feature wayland and Linux only.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Destroy

destroy the color management interface for a surface

Destroy the wp_color_management_surface_feedback_v1 object.

This is a destructor, once received this object cannot be used any longer.



GetPreferred

get the preferred image description

If this protocol object is inert, the protocol error inert is raised.

The preferred image description represents the compositor’s preferred color encoding for this wl_surface at the current time. There might be performance and power advantages, as well as improved color reproduction, if the image description of a content update matches the preferred image description.

This creates a new wp_image_description_v1 object for the currently preferred image description for the wl_surface. The client should stop using and destroy the image descriptions created by earlier invocations of this request for the associated wl_surface. This request is usually sent as a reaction to the preferred_changed event or when creating a wp_color_management_surface_feedback_v1 object if the client is capable of adapting to image descriptions.

The created wp_image_description_v1 object preserves the preferred image description of the wl_surface from the time the object was created.

The resulting image description object allows get_information request.

If the image description is parametric, the client should set it on its wl_surface only if the image description is an exact match with the client content. Particularly if everything else matches, but the target color volume is greater than what the client needs, the client should create its own parameric image description with its exact parameters.

If the interface version is inadequate for the preferred image description, meaning that the client does not support all the events needed to deliver the crucial information, the resulting image description object shall immediately deliver the wp_image_description_v1.failed event with the low_version cause, otherwise the object shall immediately deliver the ready event.

Fields

image_description: New<WpImageDescriptionV1>


GetPreferredParametric

get the preferred image description

The same description as for get_preferred applies, except the returned image description is guaranteed to be parametric. This is meant for clients that can only deal with parametric image descriptions.

If the compositor doesn’t support parametric image descriptions, the unsupported_feature error is emitted.

Fields

image_description: New<WpImageDescriptionV1>

Implementations



impl Request

pub fn opcode(&self) -> u16

Get the opcode number of this message