Struct WpColorManagementSurfaceFeedbackV1
pub struct WpColorManagementSurfaceFeedbackV1 { /* private fields */ }wayland and Linux only.Expand description
color management extension to a surface
A wp_color_management_surface_feedback_v1 allows the client to get the preferred image description of a surface.
If the wl_surface associated with this object is destroyed, the wp_color_management_surface_feedback_v1 object becomes inert.
See also the Request enum for this interface.
Implementations
impl WpColorManagementSurfaceFeedbackV1
impl WpColorManagementSurfaceFeedbackV1
pub fn preferred_changed(&self, identity: u32)
pub fn preferred_changed(&self, identity: u32)
the preferred image description changed (32-bit)
Starting from interface version 2, ‘preferred_changed2’ is sent instead of this event. See the ‘preferred_changed2’ event for the definition.
pub fn preferred_changed2(&self, identity_hi: u32, identity_lo: u32)
pub fn preferred_changed2(&self, identity_hi: u32, identity_lo: u32)
the preferred image description changed
The preferred image description is the one which likely has the most performance and/or quality benefits for the compositor if used by the client for its wl_surface contents. This event is sent whenever the compositor changes the wl_surface’s preferred image description.
This event sends the identity of the new preferred state as the argument, so clients who are aware of the image description already can reuse it. Otherwise, if the client client wants to know what the preferred image description is, it shall use the get_preferred request.
The preferred image description is not automatically used for anything. It is only a hint, and clients may set any valid image description with set_image_description, but there might be performance and color accuracy improvements by providing the wl_surface contents in the preferred image description. Therefore clients that can, should render according to the preferred image description